"ensembleNobs.ensembleData" <-
function (x) 
{
 nrow(x)
}

